\name{back.search}
\alias{back.search}
\alias{p.1clust}
\alias{printClist}
\alias{ridge.coef}
\title{Internal functions for Supervised Grouping}
\description{
  These are not to be called by the user.
}
\seealso{\code{\link{pelora}} and \code{\link{wilma}}}
\keyword{cluster}
\keyword{classif}




\eof
\name{coef.pelora}
\alias{coef.pelora}
\title{Extract the Model Coefficients of Pelora}
\description{Yields the coefficients of the penalized logistic
  regression model that is fitted by \code{pelora} with its groups of
  predictor variables (genes) as input}
\usage{
coef.pelora(object, ...)
}
\arguments{
  \item{object}{An \R object of \code{\link{class}} \code{"pelora"},
    typically the result of \code{\link{pelora}()}.}
  \item{\dots}{Further arguments passed to and from methods.}
}
\value{A numeric vector of length \eqn{\code{noc}+1}, giving the
  penalized logistic regression coefficients for the intercept and the
  \code{noc} groups and/or single variables identified by \code{pelora}.}
\references{
  Marcel Dettling (2003)
  \emph{Finding Groups of Predictive Genes from Microarray Data}, see
  \url{http://stat.ethz.ch/~dettling/supervised.html}

  Marcel Dettling and Peter Bhlmann (2004).
  Finding Predictive Gene Groups from Microarray Data.
  To appear in the \emph{Journal of Multivariate Analysis}.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{pelora}}}
\examples{
 ## Running the examples of Pelora's help page
 example(pelora, echo = FALSE)
 coef(fit)
}
\keyword{classif}
\keyword{cluster}

\eof
\name{dlda}
\alias{dlda}
\alias{nnr}
\alias{logreg}
\alias{aggtrees}
\title{Classification with Wilma's Clusters}
\description{The four functions \code{nnr} (nearest neighbor rule),
  \code{dlda} (diagonal linear discriminant analysis), \code{logreg}
  (logistic regression) and \code{aggtrees} (aggregated trees) are used
  for binary classification with the cluster representatives of Wilma's
  output.} 
\usage{
dlda(xlearn, xtest, ylearn)
nnr(xlearn, xtest, ylearn)
logreg(xlearn, xtest, ylearn)
aggtrees(xlearn, xtest, ylearn)
}

\arguments{
  \item{xlearn}{Numeric matrix of explanatory variables (\eqn{q}
    variables in columns, \eqn{n} cases in rows), containing the learning
    or training data. Typically, these are the (gene) cluster
    representatives of Wilma's output.} 
  \item{xtest}{A numeric matrix of explanatory variables (\eqn{q}
    variables in columns, \eqn{m} cases in rows), containing the test or
    validation data. Typically, these are the fitted (gene) cluster
    representatives of Wilma's output for the training data, obtained
    from \code{predict.wilma}.} 
  \item{ylearn}{Numeric vector of length \eqn{n} containing the class labels
    for the training observations. These labels have to be coded by 0 and 1.}
}
\details{\code{nnr} implements the 1-nearest-neighbor-rule with
  Euclidean distance function. \code{dlda} is linear discriminant
  analysis, using the restriction that the covariance matrix is diagonal
  with equal variance for all predictors. \code{logreg} is default
  logistic regression. \code{aggtrees} fits a default stump (a
  classification tree with two terminal nodes) by \code{rpart} for every
  predictor variable and uses majority voting to determine the final
  classifier.}
}
\value{Numeric vector of length \eqn{m}, containing the predicted class
  labels for the test observations. The class labels are coded by 0 and
  1.}
\references{
  Marcel Dettling (2002)
  \emph{Supervised Clustering of Genes}, see
  \url{http://stat.ethz.ch/~dettling/supercluster.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{wilma}}}
\examples{
## Generating random learning data: 20 observations and 10 variables (clusters)
set.seed(342)
xlearn <- matrix(rnorm(200), nrow = 20, ncol = 10)

## Generating random test data: 8 observations and 10 variables(clusters)
xtest  <- matrix(rnorm(80),  nrow = 8,  ncol = 10)

## Generating random class labels for the learning data
ylearn <- as.numeric(runif(20)>0.5)

## Predicting the class labels for the test data
nnr(xlearn, xtest, ylearn)
dlda(xlearn, xtest, ylearn)
logreg(xlearn, xtest, ylearn)
aggtrees(xlearn, xtest, ylearn)
}
\keyword{classif}

\eof
\name{fitted.pelora}
\alias{fitted.pelora}
\title{Extract the Fitted Values of Pelora}
\description{Yields the fitted values, i.e. the centroids of the (gene)
  groups that have been identified by \code{pelora}.}
\usage{
fitted.pelora(object, \dots)
}
\arguments{
  \item{object}{An \R object of \code{\link{class}} \code{"pelora"},
    typically the result of \code{\link{pelora}()}.}
  \item{\dots}{Further arguments passed to and from methods.}
}
\value{
  Numeric matrix of fitted values (for \eqn{n} cases in rows, and
  \code{noc} group centroids in columns).
}
\references{
  Marcel Dettling (2003)
  \emph{Finding Groups of Predictive Genes from Microarray Data}, see
  \url{http://stat.ethz.ch/~dettling/supervised.html}

  Marcel Dettling and Peter Bhlmann (2004).
  Finding Predictive Gene Groups from Microarray Data.
  To appear in the \emph{Journal of Multivariate Analysis}.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{pelora}}}
\examples{
 ## Running the examples of Pelora's help page
 example(pelora, echo = FALSE)
 fitted(fit)
}
\keyword{classif}
\keyword{cluster}

\eof
\name{fitted.wilma}
\alias{fitted.wilma}
\title{Extract the Fitted Values of Wilma}
\description{Yields the fitted values, i.e. the centroids of the (gene)
  clusters that have been found by \code{wilma}.}
\usage{
fitted.wilma(object, \dots)
}
\arguments{
  \item{object}{An \R object of \code{\link{class}} \code{"wilma"},
    typically the result of \code{\link{wilma}()}.}
  \item{\dots}{Further arguments passed to and from methods.}
}
\value{
  Numeric matrix of fitted values (for \eqn{n} cases in rows, and
  \code{noc} group centroids in columns).
}
\references{
  Marcel Dettling (2002)
  \emph{Supervised Clustering of Genes}, see
  \url{http://stat.ethz.ch/~dettling/supercluster.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{wilma}}}
\examples{
 ## Running the examples of Wilma's help page
 example(wilma, echo = FALSE)
 fitted(fit)
}
\keyword{classif}
\keyword{cluster}

\eof
\name{leukemia}
\docType{data}
\alias{leukemia}
\alias{leukemia.x}
\alias{leukemia.y}
\alias{leukemia.z}
\title{A part of the Golub's famous AML/ALL-leukemia dataset}
\description{Part of the training set of the famous AML/ALL-leukemia
  dataset from the Whitehead Institute.  It has been reduced to 250
  genes, about half of which are very informative for classification,
  whereas the other half was chosen randomly.
}
\usage{
data(leukemia)
}
\format{Contains three \R-objects:
  The expression matrix \code{leukemia.x},
  the associated binary response variable \code{leukemia.y},
  and the associated 3-class response variable \code{leukemia.z}.
}
\source{\url{http://www.genome.wi.mit.edu/MPR/}}
\references{
  First published in\cr
  Golub et al. (1999)
  Molecular Classification of Cancer: Class Discovery and Class
  Prediction by Gene Expression Monitoring.
  \emph{Science} \bold{286}, 531--538.
}
\author{Marcel Dettling}
\examples{
data(leukemia, package="supclust")
str(leukemia.x)
str(leukemia.y)
str(leukemia.z)
op <- par(mfrow= 1:2)
plot(leukemia.x[,56], leukemia.y)
plot(leukemia.x[,174],leukemia.z)
par(op)
}
\keyword{datasets}




\eof
\name{margin}
\alias{margin}
\title{Classification Margin Between Two Sample Classes}
\description{
  For a set of \eqn{n} observations grouped into two classes (for
  example \eqn{n} expression values of a gene), the \code{margin}
  function measures the size of the gap between the classes. This is the
  distance between the observation of response class zero having the
  lowest value, and the individual of with response one having the
  highest value.
}
\usage{
margin(x, resp)
}
\arguments{
  \item{x}{Numeric vector of length \eqn{n}, for example containing gene
    or cluster expression values of \eqn{n} different cases.}
  \item{resp}{Numeric vector of length \eqn{n} containing the ``binary''
    class labels of the cases.  Must be coded by \code{0} and \code{1}.}
}
\value{A numeric value, the \code{margin}. Positive \code{margin}
  indicates perfect separation of the response classes, whereas negative
  \code{margin} means imperfect separation.}
\references{
  Marcel Dettling (2002)
  \emph{Supervised Clustering of Genes}, see
  \url{http://stat.ethz.ch/~dettling/supercluster.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{wilma}}, \code{\link{score}} is the second statistic
  that is used there. 
}
\examples{
data(leukemia, package="supclust")
op <- par(mfrow=c(1,3))
plot(leukemia.x[,69],leukemia.y)
title(paste("Margin = ", round(margin(leukemia.x[,69], leukemia.y),2)))

## Sign-flipping is very important
plot(leukemia.x[,161],leukemia.y)
title(paste("Margin = ", round(margin(leukemia.x[,161], leukemia.y),2)))
x <- sign.flip(leukemia.x, leukemia.y)$flipped.matrix
plot(x[,161],leukemia.y)
title(paste("Margin = ", round(margin(x[,161], leukemia.y),2)))
par(op)
}
\keyword{htest}

\eof
\name{pelora}
\alias{pelora}
\title{Supervised Grouping of Predictor Variables}
\description{Performs selection and supervised grouping of predictor
  variables in large (microarray gene expression) datasets, with an
  option for simultaneous classification. Works in a greedy forward
  strategy and optimizes the binomial log-likelihood, based on estimated
  conditional probabilities from penalized logistic regression analysis.}
\usage{
pelora(x, y, u = NULL, noc = 10, lambda = 1/32, flip = "pm",
       standardize = TRUE, trace = 1)
}

\arguments{
  \item{x}{Numeric matrix of explanatory variables (\eqn{p} variables in
    columns, \eqn{n} cases in rows). For example, these can be
    microarray gene expression data which should be grouped.}
  \item{y}{Numeric vector of length \eqn{n} containing the class labels
    of the individuals. These labels have to be coded by 0 and 1.}
  \item{u}{Numeric matrix of additional (clinical) explanatory variables
    (\eqn{m} variables in columns, \eqn{n} cases in rows) that are used
    in the (penalized logistic regression) prediction model, but neither
    grouped nor averaged. For example, these can be 'traditional'
    clinical variables.}
  \item{noc}{Integer, the number of clusters that should be searched for
    on the data.}
  \item{lambda}{Real, defaults to 1/32. Rescaled penalty parameter that
    should be in \eqn{[0,1]}.}
  \item{flip}{Character string, describing a method how the \code{x}
    (gene expression) matrix should be sign-flipped. Possible are
    \code{"pm"} (the default) where the sign for each variable is
    determined upon its entering into the group, \code{"cor"} where the
    sign for each variable is determined a priori as the sign of the
    empirical correlation of that variable with the \code{y}-vector, and
    \code{"none"} where no sign-flipping is carried out.}
  \item{standardize}{Logical, defaults to \code{TRUE}. Is indicating
    whether the predictor variables (genes) should be standardized to
    zero mean and unit variance.}
  \item{trace}{Integer >= 0; when positive, the output of the internal
    loops is provided; \code{trace >= 2} provides output even from the
    internal C routines.}
}
\value{
  \code{pelora} returns an object of class "pelora". The functions
  \code{print} and \code{summary} are used to obtain an overview of the
  variables (genes) that have been selected and the groups that have
  been formed. The function \code{plot} yields a two-dimensional
  projection into the space of the first two group centroids that
  \code{pelora} found. The generic function \code{fitted} returns
  the fitted values, these are the cluster representatives. \code{coef}
  returns the penalized logistic regression coefficients \eqn{\theta_j}
  for each of the predictors. Finally, \code{predict} is used for
  classifying test data with Pelora's internal penalized logistic
  regression classifier on the basis of the (gene) groups that have been
  found. 

  An object of class "pelora" is a list containing:
  \item{genes}{A list of length \code{noc}, containing integer vectors
    consisting of the indices (column numbers) of the variables (genes)
    that have been clustered.}
  \item{values}{A numerical matrix with dimension \eqn{n \times
      \code{noc}}, containing the fitted values, i.e. the group
    centroids \eqn{\tilde{x}_j}.}
  \item{y}{Numeric vector of length \eqn{n} containing the class labels
    of the individuals. These labels are coded by 0 and 1.}
  \item{steps}{Numerical vector of length \code{noc}, showing the number
    of forward/backward cycles in the fitting process of each cluster.}
  \item{lambda}{The rescaled penalty parameter.}
  \item{noc}{The number of clusters that has been searched for on the data.}
  \item{px}{The number of columns (genes) in the \code{x}-matrix.}
  \item{flip}{The method that has been chosen for sign-flipping the
    \code{x}-matrix.}
  \item{var.type}{A factor with \code{noc} entries, describing whether
    the \eqn{j}th predictor is a group of predictors (genes) or a single
    (clinical) predictor variable.}
  \item{crit}{A list of length \code{noc}, containing numerical vectors
    that provide information about the development of the grouping
    criterion during the clustering.}
  \item{signs}{Numerical vector of length \eqn{p}, saying whether the
    \eqn{i}th variable (gene) should be sign-flipped (-1) or not (+1).}
  \item{samp.names}{The names of the samples (rows) in the
    \code{x}-matrix.}
  \item{gene.names}{The names of the variables (columns) in the
    \code{x}-matrix.}
  \item{call}{The function call.}
}
\references{
  Marcel Dettling (2003)
  \emph{Finding Predictive Gene Groups from Microarray Data}, see
  \url{http://stat.ethz.ch/~dettling/supervised.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.

  Marcel Dettling and Peter Bhlmann (2004).
  Finding Predictive Gene Groups from Microarray Data.
  To appear in the \emph{Journal of Multivariate Analysis}
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{wilma}} for another supervised clustering technique.}
\examples{
## Working with a "real" microarray dataset
data(leukemia, package="supclust")

## Generating random test data: 3 observations and 250 variables (genes)
set.seed(724)
xN <- matrix(rnorm(750), nrow = 3, ncol = 250)

## Fitting Pelora
fit <- pelora(leukemia.x, leukemia.y, noc = 3)

## Working with the output
fit
summary(fit)
plot(fit)
fitted(fit)
coef(fit)

## Fitted values and class probabilities for the training data
predict(fit, type = "cla")
predict(fit, type = "prob")

## Predicting fitted values and class labels for the random test data
predict(fit, newdata = xN)
predict(fit, newdata = xN, type = "cla", noc = c(1,2,3))
predict(fit, newdata = xN, type = "pro", noc = c(1,3))

## Fitting Pelora such that the first 70 variables (genes) are not grouped
fit <- pelora(leukemia.x[, -(1:70)], leukemia.y, leukemia.x[,1:70])

## Working with the output
fit
summary(fit)
plot(fit)
fitted(fit)
coef(fit)

## Fitted values and class probabilities for the training data
predict(fit, type = "cla")
predict(fit, type = "prob")

## Predicting fitted values and class labels for the random test data
predict(fit, newdata = xN[, -(1:70)], newclin = xN[, 1:70])
predict(fit, newdata = xN[, -(1:70)], newclin = xN[, 1:70], "cla", noc  = 1:10)
predict(fit, newdata = xN[, -(1:70)], newclin = xN[, 1:70], type = "pro")
}
\keyword{classif}
\keyword{cluster}



\eof
\name{plot.pelora}
\alias{plot.pelora}
\title{2-Dimensional Visualization of Pelora's Output}
\description{Yields a projection of the cases (for example \eqn{n} gene 
  expression profiles) into the space of the first two gene group
  centroids that were identified by \code{pelora}.}
\usage{
plot.pelora(x, main = "2-Dimensional Projection Pelora's output",
            xlab = NULL, ylab = NULL, col = seq(x$yvals), ...)
}
\arguments{
  \item{x}{An \R object of \code{\link{class}} \code{"pelora"},
    typically the result of \code{\link{pelora}()}.}
  \item{main}{A character string, giving the title of the plot.}
  \item{xlab}{A character string, giving the annotation of the
    \code{x}-axis.}
  \item{ylab}{A character string, giving the annotation of the
    \code{x}-axis.}
  \item{col}{A numeric vector of length 2, coding the colors that will
    be used for plotting the class labels.}
  \item{\dots}{Further arguments passed to and from methods.}
}
\references{
  Marcel Dettling (2003)
  \emph{Finding Groups of Predictive Genes from Microarray Data}, see
  \url{http://stat.ethz.ch/~dettling/supervised.html}

  Marcel Dettling and Peter Bhlmann (2004).
  Finding Predictive Gene Groups from Microarray Data.
  To appear in the \emph{Journal of Multivariate Analysis}.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{pelora}}}
\examples{
 ## Running the examples of Pelora's help page
 example(pelora, echo = FALSE)
 plot(fit)
}
\keyword{classif}
\keyword{cluster}


\eof
\name{plot.wilma}
\alias{plot.wilma}
\title{2-Dimensional Visualization of Wilma's Output}
\description{Yields a projection of the cases (for example \eqn{n} gene 
  expression profiles) into the space of the first two gene group
  centroids that were identified by \code{wilma}.}
\usage{
plot.wilma(x, xlab = NULL, ylab = NULL, col = seq(x$yvals),
           main = "2-Dimensional Projection of Wilma's Output", ...)
}
\arguments{
  \item{x}{An \R object of \code{\link{class}} \code{"wilma"},
    typically the result of \code{\link{wilma}()}.}
  \item{xlab}{A character string, giving the annotation of the
    \code{x}-axis.}
  \item{ylab}{A character string, giving the annotation of the
    \code{x}-axis.}
  \item{col}{A numeric vector of length 2, coding the colors that will
    be used for plotting the class labels.}
  \item{main}{A character string, giving the title of the plot.}
  \item{\dots}{Further arguments passed to and from methods.}
}
\references{
  Marcel Dettling (2002)
  \emph{Supervised Clustering of Genes}, see
  \url{http://stat.ethz.ch/~dettling/supercluster.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{wilma}}}
\examples{
 ## Running the examples of Wilma's help page
 example(wilma, echo = FALSE)
 plot(fit)
}
\keyword{classif}
\keyword{cluster}

\eof
\name{predict.pelora}
\alias{predict.pelora}
\title{Predict Method for Pelora}
\description{Yields fitted values, predicted class labels and
  conditional probability estimates for training and test data, which
  are based on the gene groups \code{pelora} found, and on its internal
  penalized logistic regression classifier.}
\usage{
predict.pelora(object, newdata = NULL, newclin = NULL,
               type = c("fitted", "probs", "class"), noc = object$noc, ...)
}
\arguments{
  \item{object}{An \R object of \code{\link{class}} \code{"pelora"},
    typically the result of \code{\link{pelora}()}.}
  \item{newdata}{Numeric matrix with the same number of explanatory
    variables as the original \code{x}-matrix (\eqn{p} variables in
    columns, \eqn{r} cases in rows). For example, these can be
    additional microarray gene expression data which should be
    predicted.}  
  \item{newclin}{Numeric matrix with the same number of additional
    (clinical) explanatory variables as the original \code{u}-matrix
    (\eqn{m} variables in columns, \eqn{r} cases in rows) that are used 
    in the (penalized logistic regression) prediction model, but neither
    grouped nor averaged. Only needs to be given, if the model fit
    included an \code{u}-matrix. For example, these can be 'traditional'
    clinical variables.}
  \item{type}{Character string, describing whether fitted values
    \code{"fitted"}, estimated conditional probabilites \code{"probs"}
    or class labels \code{"class"} should be returned.}
  \item{noc}{Integer, saying with how many clusters the fitted values,
    probability estimates or class labels should be determined. Also
    numeric vectors are allowed as an argument. The output is then a
    numeric matrix with fitted values, probability estimates or class
    labels for a multiple number of clusters.}
  \item{\dots}{Further arguments passed to and from methods.}
}
\details{
  If \code{newdata = NULL}, then the in-sample fitted values,
  probability estimates and class label predictions are returned.
}
\value{
  Depending on whether \code{noc} is a single number or a numeric
  vector. In the first case, a numeric vector of length \eqn{r} is
  returned, which contains fitted values for \code{noc} clusters, or
  probability estimates/class label predictions with \code{noc}
  clusters.

  In the latter case, a numeric matrix with \code{length(noc)} columns,
  each containing fitted values for \code{noc} clusters, or
  probability estimates/class label predictions with \code{noc}
  clusters, is returned.}
}
\references{
  Marcel Dettling (2003)
  \emph{Finding Groups of Predictive Genes from Microarray Data}, see
  \url{http://stat.ethz.ch/~dettling/supervised.html}

  Marcel Dettling and Peter Bhlmann (2004).
  Finding Predictive Gene Groups from Microarray Data.
  To appear in the \emph{Journal of Multivariate Analysis}.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{pelora}}}
\examples{
## Working with a "real" microarray dataset
data(leukemia, package="supclust")

## Generating random test data: 3 observations and 250 variables (genes)
set.seed(724)
xN <- matrix(rnorm(750), nrow = 3, ncol = 250)

## Fitting Pelora
fit <- pelora(leukemia.x, leukemia.y, noc = 3)

## Fitted values and class probabilities for the training data
predict(fit, type = "cla")
predict(fit, type = "prob")

## Predicting fitted values and class labels for the random test data
predict(fit, newdata = xN)
predict(fit, newdata = xN, type = "cla", noc = c(1,2,3))
predict(fit, newdata = xN, type = "pro", noc = c(1,3))

## Fitting Pelora such that the first 70 variables (genes) are not grouped
fit <- pelora(leukemia.x[, -(1:70)], leukemia.y, leukemia.x[,1:70])

## Fitted values and class probabilities for the training data
predict(fit, type = "cla")
predict(fit, type = "prob")

## Predicting fitted values and class labels for the random test data
predict(fit, newdata = xN[, -(1:70)], newclin = xN[, 1:70])
predict(fit, newdata = xN[, -(1:70)], newclin = xN[, 1:70], "cla", noc  = 1:10)
predict(fit, newdata = xN[, -(1:70)], newclin = xN[, 1:70], type = "pro")
}
\keyword{classif}
\keyword{cluster}

\eof
\name{predict.wilma}
\alias{predict.wilma}
\title{Predict Method for Wilma}
\description{Yields fitted values or predicted class labels for training
  and test data, which are based on the supervised gene clusters
  \code{wilma} found, and on a choice of four different classifiers: the
  nearest-neighbor rule, diagonal linear discriminant analysis, logistic
  regression and aggregated trees.}
\usage{
predict.wilma(object, newdata = NULL, type = c("fitted", "class"),
              classifier = c("nnr", "dlda", "logreg", "aggtrees"),
              noc = object$noc, ...)
}
\arguments{
  \item{object}{An \R object of \code{\link{class}} \code{"wilma"},
    typically the result of \code{\link{wilma}()}.}
  \item{newdata}{Numeric matrix with the same number of explanatory
    variables as the original \code{x}-matrix (\eqn{p} variables in
    columns, \eqn{r} cases in rows). For example, these can be
    additional microarray gene expression data which should be
    predicted.}
  \item{type}{Character string, describing whether fitted values
    \code{"fitted"} or predicted class labels \code{"class"} should be
    returned.}
  \item{classifier}{Character string, saying which classifier should be
    used. Choices are \code{"nnr"}, the 1-nearest-neighbor-rule;
    \code{"dlda"}, diagonal linear discriminant analysis;
    \code{"logreg"}, logistic regression; \code{"aggtrees"} aggregated
    trees. }
  \item{noc}{Integer, saying with how many clusters the fitted values or
    class label predictions should be determined. Also numeric vectors
    are allowed as an argument. The output is then a numeric matrix with
    fitted values or class label predictions for a multiple number of
    clusters.} 
  \item{\dots}{}
}
\details{
  If \code{newdata = NULL}, then the in-sample fitted values or class
  label predictions are returned. 
}
\value{
  Depending on whether \code{noc} is a single number or a numeric
  vector. In the first case, a numeric vector of length \eqn{r} is
  returned, which contains fitted values for \code{noc} clusters, or
  class label predictions with \code{noc} clusters.

  In the latter case, a numeric matrix with \code{length(noc)} columns,
  each containing fitted values for \code{noc} clusters, or class label
  predictions with \code{noc} clusters, is returned.
}
\references{
  Marcel Dettling (2002)
  \emph{Supervised Clustering of Genes}, see
  \url{http://stat.ethz.ch/~dettling/supercluster.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{wilma}} and for the four classifiers,
  \code{\link{nnr}}, \code{\link{dlda}}, \code{\link{logreg}},
  \code{\link{aggtrees}}.}
\examples{
## Working with a "real" microarray dataset
data(leukemia, package="supclust")

## Generating random test data: 3 observations and 250 variables (genes)
set.seed(724)
xN <- matrix(rnorm(750), nrow = 3, ncol = 250)

## Fitting Wilma
fit  <- wilma(leukemia.x, leukemia.y, noc = 3, trace = 1)

## Fitted values and class predictions for the training data
predict(fit, type = "cla")
predict(fit, type = "fitt")

## Predicting fitted values and class labels for test data
predict(fit, newdata = xN)
predict(fit, newdata = xN, type = "cla", classifier = "nnr", noc = c(1,2,3))
predict(fit, newdata = xN, type = "cla", classifier = "dlda", noc = c(1,3))
predict(fit, newdata = xN, type = "cla", classifier = "logreg")
predict(fit, newdata = xN, type = "cla", classifier = "aggtrees")
}
\keyword{classif}
\keyword{cluster}

\eof
\name{print.pelora}
\alias{print.pelora}
\title{Print Method for Pelora Objects}
\description{Yields an overview about the type, size and final criterion
  value of the predictor variables that were selected by \code{pelora}.}
\usage{
print.pelora(x, digits = getOption("digits"), details = FALSE, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{An \R object of \code{\link{class}} \code{"pelora"},
    typically the result of \code{\link{pelora}()}.}
  \item{digits}{The number of digits that should be printed.}
  \item{details}{Logical, defaults to \code{FALSE}. If set to
    \code{TRUE}, the output corresponds to
    \code{\link{summary.pelora}}.}
  \item{\dots}{Further arguments passed to and from methods.}
}
\references{
  Marcel Dettling (2003)
  \emph{Finding Groups of Predictive Genes from Microarray Data}, see
  \url{http://stat.ethz.ch/~dettling/supervised.html}

  Marcel Dettling and Peter Bhlmann (2004).
  Finding Predictive Gene Groups from Microarray Data.
  To appear in the \emph{Journal of Multivariate Analysis}.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{pelora}}}
\examples{
 ## Running the examples of Pelora's help page
 example(pelora, echo = FALSE)
 print(fit)
}
\keyword{classif}
\keyword{cluster}

\eof
\name{print.wilma}
\alias{print.wilma}
\title{Print Method for Wilma Objects}
\description{Yields an overview about the size and the final criterion
  values of the clusters that were selected by \code{wilma}.}
\usage{
print.wilma(x, ...)
}
\arguments{
  \item{x}{An \R object of \code{\link{class}} \code{"wilma"},
    typically the result of \code{\link{wilma}()}.}
  \item{\dots}{Further arguments passed to and from methods.}
}
\references{
  Marcel Dettling (2002)
  \emph{Supervised Clustering of Genes}, see
  \url{http://stat.ethz.ch/~dettling/supercluster.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{wilma}}}
\examples{
 ## Running the examples of Wilma's help page
 example(wilma, echo = FALSE)
 print(fit)
}
\keyword{classif}
\keyword{cluster}

\eof
\name{score}
\alias{score}
\title{Wilcoxon Score for Binary Problems}
\description{For a set of \eqn{n} observations grouped into two classes (for
  example \eqn{n} expression values of a gene), the \code{score}
  function measures the separation of the classes. It can be interpreted
  as counting for each observation having response zero, the number of
  individuals of response class one that are smaller, and summing up
  these quantities.}
\usage{
score(x, resp)
}
\arguments{
  \item{x}{Numeric vector of length \eqn{n}, for example containing gene
    or cluster expression values of \eqn{n} different cases.}
  \item{resp}{Numeric vector of length \eqn{n} containing the ``binary''
    class labels of the cases.  Must be coded by \code{0} and \code{1}.}
}
\value{A numeric value, the \code{score}. The minimal \code{score} is
  zero, the maximal \code{score} is the product of the number of samples
  in class 0 and class 1. Values near the minimal or maximal
  \code{score} indicate good separation, whereas intermediate
  \code{score} means poor separation.}
\references{
  Marcel Dettling (2002)
  \emph{Supervised Clustering of Genes}, see
  \url{http://stat.ethz.ch/~dettling/supercluster.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{wilma}}, \code{\link{margin}} is the second statistic
  that is used there. 
}
\examples{
data(leukemia, package="supclust")
op <- par(mfrow=c(1,3))
plot(leukemia.x[,69],leukemia.y)
title(paste("Score = ", score(leukemia.x[,69], leukemia.y)))

## Sign-flipping is very important
plot(leukemia.x[,161],leukemia.y)
title(paste("Score = ", score(leukemia.x[,161], leukemia.y),2))
x <- sign.flip(leukemia.x, leukemia.y)$flipped.matrix
plot(x[,161],leukemia.y)
title(paste("Score = ", score(x[,161], leukemia.y),2))
par(op)
}
\keyword{htest}

\eof
\name{sign.change}
\alias{sign.change}
\title{Sign-flipping of Predictor Variables to Obtain Equal Polarity}
\description{Computes the empirical correlation for each predictor
  variable (gene) in the \code{x}-Matrix with the response \code{y}, and
  multiplies its values with (-1) if the empirical correlation has a
  negative sign. For gene expression data, this amounts to treating
  under- and overexpression symmetrically. After the \code{sign.change},
  low (expression) values point towards response class 0 and high
  (expression) values point towards class 1.}
\usage{
sign.change(x, y)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{Numeric matrix of explanatory variables (\eqn{p} variables in
    columns, \eqn{n} cases in rows). For example, these can be
    microarray gene expression data which should be sign-flipped and
    then grouped.}
  \item{y}{Numeric vector of length \eqn{n} containing the class labels
    of the individuals. These labels have to be coded by 0 and 1.}
}
\value{
  Returns a list containing:
  \item{x.new}{The sign-flipped \code{x}-matrix.}
  \item{signs}{Numeric vector of length \eqn{p}, which for each
    predictor variable indicates whether it was sign-flipped (coded by
    -1) or not (coded by +1).}
}
\references{
  Marcel Dettling (2003)
  \emph{Finding Groups of Predictive Genes from Microarray Data}, see
  \url{http://stat.ethz.ch/~dettling/supervised.html}

  Marcel Dettling and Peter Bhlmann (2004).
  Finding Predictive Gene Groups from Microarray Data.
  To appear in the \emph{Journal of Multivariate Analysis}.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{pelora}}, as well as for older methodology,
  \code{\link{wilma}} and \code{\link{sign.flip}}.}
\examples{
data(leukemia, package="supclust")

op <- par(mfrow=c(1,3))
plot(leukemia.x[,69],leukemia.y)
title(paste("Margin = ", round(margin(leukemia.x[,69], leukemia.y),2)))

## Sign-flipping is very important
plot(leukemia.x[,161],leukemia.y)
title(paste("Margin = ", round(margin(leukemia.x[,161], leukemia.y),2)))
x <- sign.change(leukemia.x, leukemia.y)$x.new
plot(x[,161],leukemia.y)
title(paste("Margin = ", round(margin(x[,161], leukemia.y),2)))
par(op)
}
\keyword{manip}

\eof
\name{sign.flip}
\alias{sign.flip}
\title{Sign-flipping of Predictor Variables to Obtain Equal Polarity}
\description{Computes the \code{score} for each predictor variable
  (gene) in the \code{x}-Matrix, and multiplies its values with (-1) if
  its \code{score} is greater or equal than half of the maximal
  \code{score}. For gene expression data, this amounts to treating
  under- and overexpression symmetrically. After the sign-flip
  procedure, low (expression) values point towards response class 0 and
  high (expression) values point towards class 1.}
\usage{
sign.flip(x, y)
}
\arguments{
  \item{x}{Numeric matrix of explanatory variables (\eqn{p} variables in
    columns, \eqn{n} cases in rows). For example, these can be
    microarray gene expression data which should be sign-flipped and
    then clustered.}
  \item{y}{Numeric vector of length \eqn{n} containing the class labels
    of the individuals. These labels have to be coded by 0 and 1.}
}
\value{Returns a list containing:
  \item{flipped.matrix}{The sign-flipped \code{x}-matrix.}
  \item{signs}{Numeric vector of length \eqn{p}, which for each
    predictor variable indicates whether it was sign-flipped (coded by
    -1) or not (coded by +1).}
}
\references{
  Marcel Dettling (2002)
  \emph{Supervised Clustering of Genes}, see
  \url{http://stat.ethz.ch/~dettling/supercluster.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{wilma}} and \code{\link{score}}, as well as for a
  newer methodology, \code{\link{pelora}} and \code{\link{sign.change}}.}
\examples{
data(leukemia, package="supclust")

op <- par(mfrow=c(1,3))
plot(leukemia.x[,69],leukemia.y)
title(paste("Margin = ", round(margin(leukemia.x[,69], leukemia.y),2)))

## Sign-flipping is very important
plot(leukemia.x[,161],leukemia.y)
title(paste("Margin = ", round(margin(leukemia.x[,161], leukemia.y),2)))
x <- sign.flip(leukemia.x, leukemia.y)$flipped.matrix
plot(x[,161],leukemia.y)
title(paste("Margin = ", round(margin(x[,161], leukemia.y),2)))
par(op)# reset
}
\keyword{manip}

\eof
\name{standardize.genes}
\alias{standardize.genes}
\title{Standardization of Predictor Variables}
\description{Standardizes each column (gene) of the \code{x}-matrix to
  zero mean and unit variance. This function is not to be called by the
  user, the standardization is handled internally in \code{pelora}.}
\usage{
standardize.genes(exmat)
}
\arguments{
  \item{exmat}{Numeric matrix of explanatory variables (\eqn{p}
    variables in columns, \eqn{n} cases in rows). For example, these can
    be microarray gene expression data which should be standardized and
    then grouped.}
}
\value{
  Returns a list containing:
  \item{x}{The standardized \code{x}-matrix}
  \item{means}{Numeric vector of length \eqn{p}, containing the initial
    mean of each column (gene) of the \code{x}-matrix.}
  \item{sdevs}{Numeric vector of length \eqn{p}, containing the initial
    standard deviation of each column (gene) of the \code{x}-matrix.}
}
\references{
  Marcel Dettling (2003)
  \emph{Finding Groups of Predictive Genes from Microarray Data}, see
  \url{http://stat.ethz.ch/~dettling/supervised.html}

  Marcel Dettling and Peter Bhlmann (2004).
  Finding Predictive Gene Groups from Microarray Data.
  To appear in the \emph{Journal of Multivariate Analysis}.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{pelora}}}
\keyword{manip}

\eof
\name{summary.pelora}
\alias{summary.pelora}
\title{Summary Method for Pelora Objects}
\description{Yields detailed information about the variables (genes)
  that have been selected, and how they were grouped.}
\usage{
summary.pelora(object, digits, \dots)
}
\arguments{
  \item{object}{An \R object of \code{\link{class}} \code{"pelora"},
    typically the result of \code{\link{pelora}()}.}
  \item{digits}{The number of digits that should be printed.}
  \item{\dots}{Further arguments passed to and from methods.}
}
\references{
  Marcel Dettling (2003)
  \emph{Finding Groups of Predictive Genes from Microarray Data}, see
  \url{http://stat.ethz.ch/~dettling/supervised.html}

  Marcel Dettling and Peter Bhlmann (2004).
  Finding Predictive Gene Groups from Microarray Data.
  To appear in the \emph{Journal of Multivariate Analysis}.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{pelora}}}
\examples{
 ## Running the examples of Pelora's help page
 example(pelora, echo = FALSE)
 summary(fit)
}
\keyword{classif}
\keyword{cluster}

\eof
\name{summary.wilma}
\alias{summary.wilma}
\title{Summary Method for Wilma Objects}
\description{Yields detailed information about the variables (genes)
  that have been selected, and how they were clustered.}
\usage{
summary.wilma(object, ...)
}
\arguments{
  \item{object}{An \R object of \code{\link{class}} \code{"wilma"},
    typically the result of \code{\link{wilma}()}.}
  \item{\dots}{Further arguments passed to and from methods.}
}
\references{
  Marcel Dettling (2002)
  \emph{Supervised Clustering of Genes}, see
  \url{http://stat.ethz.ch/~dettling/supercluster.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{wilma}}}
\examples{
 ## Running the examples of Wilma's help page
 example(wilma, echo = FALSE)
 summary(fit)
}
\keyword{classif}
\keyword{cluster}

\eof
\name{wilma}
\alias{wilma}
\title{Supervised Clustering of Predictor Variables}
\description{Performs supervised clustering of predictor variables for
  large (microarray gene expression) datasets. Works in a greedy forward
  strategy and optimizes a combination of the Wilcoxon and Margin
  statistics for finding the clusters.}
\usage{
wilma(x, y, noc, genes = NULL, flip = TRUE, once.per.clust = FALSE, trace = 0)
}
\arguments{
  \item{x}{Numeric matrix of explanatory variables (\eqn{p} variables in
    columns, \eqn{n} cases in rows). For example, these can be
    microarray gene expression data which should be clustered.}
  \item{y}{Numeric vector of length \eqn{n} containing the class labels
    of the individuals. These labels have to be coded by 0 and 1.}
  \item{noc}{Integer, the number of clusters that should be searched for
    on the data.} 
  \item{genes}{Defaults to \code{NULL}. An optional list (of length
    \code{noc}) of vectors containing the indices (column numbers) of
    the previously known initial clusters.} 
  \item{flip}{Logical, defaults to \code{TRUE}. Is indicating whether
    the clustering should be done with or without sign-flipping.}
  \item{once.per.clust}{Logical, defaults to \code{FALSE}. Is indicating
    if each variable (gene) should only be allowed to enter into each
    cluster once; equivalently, the cluster mean profile has only
    weights \eqn{\pm 1}{+/- 1} for each variable.}
  \item{trace}{Integer >= 0; when positive, the output of the internal
    loops is provided; \code{trace >= 2} provides output even from the
    internal C routines.}
}

\value{
  \code{wilma} returns an object of class "wilma". The functions
  \code{print} and \code{summary} are used to obtain an overview of the
  clusters that have been found. The function \code{plot} yields a
  two-dimensional projection into the space of the first two clusters
  that \code{wilma} found. The generic function \code{fitted} returns
  the fitted values, these are the cluster representatives. Finally,
  \code{predict} is used for classifying test data on the basis of
  Wilma's cluster with either the nearest-neighbor-rule, diagonal linear
  discriminant analysis, logistic regression or aggregated trees.

  An object of class "wilma" is a list containing:
  \item{clist}{A list of length \code{noc}, containing integer vectors
    consisting of the indices (column numbers) of the variables (genes)
    that have been clustered.} 
  \item{steps}{Numerical vector of length \code{noc}, showing the number
    of forward/backward cycles in the fitting process of each cluster.}
  \item{y}{Numeric vector of length \eqn{n} containing the class labels
    of the individuals. These labels have to be coded by 0 and 1.}
  \item{x.means}{A list of length \code{noc}, containing numerical
    matrices consisting of the cluster representatives after insertion
    of each variable.}
  \item{noc}{Integer, the number of clusters that has been searched for
    on the data.}
  \item{signs}{Numerical vector of length \eqn{p}, saying whether the
    \eqn{i}th variable (gene) should be sign-flipped (-1) or not (+1).}
}
\references{
  Marcel Dettling (2002)
  \emph{Supervised Clustering of Genes}, see
  \url{http://stat.ethz.ch/~dettling/supercluster.html}

  Marcel Dettling and Peter Bhlmann (2002).
  Supervised Clustering of Genes.
  \emph{Genome Biology}, \bold{3}(12): research0069.1-0069.15.

  Marcel Dettling and Peter Bhlmann (2004).
  Finding Predictive Gene Groups from Microarray Data.
  To appear in the \emph{Journal of Multivariate Analysis}.
}
\author{Marcel Dettling, \email{dettling@stat.math.ethz.ch}}
\seealso{\code{\link{score}}, \code{\link{margin}}, and for a newer
  methodology, \code{\link{pelora}}.}
\examples{
## Working with a "real" microarray dataset
data(leukemia, package="supclust")

## Generating random test data: 3 observations and 250 variables (genes)
set.seed(724)
xN <- matrix(rnorm(750), nrow = 3, ncol = 250)

## Fitting Wilma
fit  <- wilma(leukemia.x, leukemia.y, noc = 3, trace = 1)

## Working with the output
fit
summary(fit)
plot(fit)
fitted(fit)

## Fitted values and class predictions for the training data
predict(fit, type = "cla")
predict(fit, type = "fitt")

## Predicting fitted values and class labels for test data
predict(fit, newdata = xN)
predict(fit, newdata = xN, type = "cla", classifier = "nnr", noc = c(1,2,3))
predict(fit, newdata = xN, type = "cla", classifier = "dlda", noc = c(1,3))
predict(fit, newdata = xN, type = "cla", classifier = "logreg")
predict(fit, newdata = xN, type = "cla", classifier = "aggtrees")
}
\keyword{cluster}

\eof
